@@ -20,7 +20,8 @@ from .conf import load_config
 from .conf import DATABASES
 from .enginemanager import EngineManager
 from .repository import RelationalDatabaseRepository
-
+from .repository import Repository
+from . import query
 
 ENGINES = EngineManager()
 ASYNC_ENGINES = EngineManager()
@@ -142,7 +143,7 @@ def create_engine(name='self', *args, **kwargs):
 
 
 def get_dsn(name='self', use_async=False):
-    """Return the Data Source Name (DSN) for the named connection."""
+    """Return the Data Source Name (DSN) for the named connection `name`."""
     global DATABASES
     return DATABASES[name].as_dsn(use_async=use_async)
 
