@@ -37,7 +37,7 @@ class EngineManager:
             engine = self.engines.pop(name)
             result = engine.dispose()
             if inspect.iscoroutine(result):
-                loop.run_until_complete(result)
+                loop.create_task(result)
 
     def __len__(self):
         return len(self.engines)
