@@ -79,7 +79,7 @@ class NamedQuery(metaclass=NamedQueryMeta):
                     if callable(p):
                         p = p(self, query)
                     if isinstance(p, selectable.Select):
-                        query = query.filter(p)
+                        query = p
                     elif isinstance(p, self.supported_predicates):
                         query = query.where(p)
                     else:
